@@ -1,5 +1,5 @@
-#  tests for fiona-1.8.9.post2-py38hb7fdc2d_0 (this is a generated file);
-print('===== testing package: fiona-1.8.9.post2-py38hb7fdc2d_0 =====');
+#  tests for fiona-1.8.11-py38hb7fdc2d_0 (this is a generated file);
+print('===== testing package: fiona-1.8.11-py38hb7fdc2d_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import os
@@ -24,7 +24,7 @@ assert(feature['properties']['RETURN_P'] is None)  # Fails
 src.close()
 #  --- run_test.py (end) ---
 
-print('===== fiona-1.8.9.post2-py38hb7fdc2d_0 OK =====');
+print('===== fiona-1.8.11-py38hb7fdc2d_0 OK =====');
 print("import: 'fiona'")
 import fiona
 
